
This is a **ACE editor widget** for for `YAFOWIL 
<http://pypi.python.org/pypi/yafowil>`_ 

- `ACE Editor <http://ace.ajax.org/#nav=about>`_
- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#ace>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.ace/index.html>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.ace>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Robert Niederrreiter <rnix [at] squarewave [dot] at>
